0.1.3
=====

* Change the installation details

  Pip 1.5 makes it difficult to specify installation sources outside of the
  PyPI. Also, this is better motivation to get these packages officially on
  PyPI.



0.1.2
=====

* Depend on specific forks of pymeta and pybars



0.1.1
=====

* First Release